function varargout = OptionsStrategies(varargin)
% OPTIONSSTRATEGIES MATLAB code for OptionsStrategies.fig
%      OPTIONSSTRATEGIES, by itself, creates a new OPTIONSSTRATEGIES or raises the existing
%      singleton*.
%
%      H = OPTIONSSTRATEGIES returns the handle to a new OPTIONSSTRATEGIES or the handle to
%      the existing singleton*.
%
%      OPTIONSSTRATEGIES('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in OPTIONSSTRATEGIES.M with the given input arguments.
%
%      OPTIONSSTRATEGIES('Property','Value',...) creates a new OPTIONSSTRATEGIES or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before OptionsStrategies_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to OptionsStrategies_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help OptionsStrategies

% Last Modified by GUIDE v2.5 19-Oct-2012 22:09:58

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @OptionsStrategies_OpeningFcn, ...
                   'gui_OutputFcn',  @OptionsStrategies_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before OptionsStrategies is made visible.
function OptionsStrategies_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to OptionsStrategies (see VARARGIN)

% Choose default command line output for OptionsStrategies
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes OptionsStrategies wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = OptionsStrategies_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in payoff.
function payoff_Callback(hObject, eventdata, handles)
% hObject    handle to payoff (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
GUI2;


% --- Executes on button press in profit.
function profit_Callback(hObject, eventdata, handles)
% hObject    handle to profit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
GUI3;